@@ -16,15 +16,15 @@ if THREAD_SAFE:
         conn = persist.connection()
         return conn
 else:
-#    from DBUtils.SteadyDB import connect
-#    def connection(*args, **kwds):
-#        kwds['maxusage'] = False
-#        return connect(MySQLdb, *args, **kwds)
-
-    def connection(*arg,**kwds):
-       conn=MySQLdb.connect(*arg,**kwds)
-       return conn
+    from DBUtils.SteadyDB import connect
+    def connection(*args, **kwds):
+        kwds['maxusage'] = False
+        return connect(MySQLdb, *args, **kwds)
 
+ #   def connection(*arg,**kwds):
+ #      conn=MySQLdb.connect(*arg,**kwds)
+ #      return conn
+ #
 
 class LogCursor(object):
     def __init__(self, cursor):
