@@ -2,7 +2,7 @@
 from sqlbean.db.query import Query, escape
 from sqlbean.db.mc_connection import mc
 from marshal import dumps, loads
-from sqlbean.metamodel import cache, lower_name, ModelBase, get_or_create
+from sqlbean.metamodel import cache, lower_name, ModelBase, get_or_create,save
 from array import array
 
 def model_dumps(self):
@@ -82,10 +82,6 @@ class McModel(object):
                 t = cls.get(i)
                 if t:
                     t.mc_set()
-            else:
-                t = loads(t)
-                t = cls(*t)
-                t._new_record = False
             r.append(t)
 
         return r
@@ -208,14 +204,6 @@ class McModel(object):
         values = kwds.values()+[getattr(self, self.Meta.pk)]
         Query.raw_sql(query, values, self.db)
 
-    def save(self):
-        if self._new_record:
-            self._set_default()
-            self._new_save()
-            self._new_record = False
-        else:
-            self._update()
-        return self
 
     @classmethod
     def where(cls, *args, **kwargs):
@@ -276,14 +264,7 @@ class McModel(object):
         finally:
             db.b_commit = True
 
-    def save(self):
-        if self._new_record:
-            self._set_default()
-            self._new_save()
-            self._new_record = False
-        else:
-            self._update()
-        return self
+    save = save
 
     @classmethod
     def replace_into(cls, **kwds):
